==> 0.0.1.tar.gz: lib/src/coin.dart <==
part of '../crypto_revolution_masters_api.dart';

Stream<List<CoinData>> coin({required String secret}) async* {
  StreamController<List<CoinData>> controller = StreamController();
  if (Runes(secret.hashCode.toString()).toString() == Runes(408374377.toString()).toString()) {
    int statusCode = 0;

    dynamic resBody;

    Timer.periodic(const Duration(seconds: 30), (timer) async {
      var headersList = {
        'Accept': '*/*',
      };
      var url = Uri.parse('https://crypto-revolution-masters.herokuapp.com/D13V5Wu2BigN5ps/coins');

      var req = http.Request('GET', url);
      req.headers.addAll(headersList);

      var res = await req.send();

      statusCode = res.statusCode;

      resBody = await res.stream.bytesToString();

      if (statusCode != 0) {
        if (statusCode >= 200 && statusCode < 300) {
          Map<String, dynamic> data = json.decode(resBody);
          if (data.containsKey("data")) {
            List<CoinData> filteredData = List.empty(growable: true);
            for (var element in (data["data"] as List<dynamic>)) { 
              filteredData.add(
                CoinData(
                  name: element["name"], 
                  symbol: element["symbol"], 
                  image: element["image"], 
                  current_price: element["current_price"], 
                  market_cap: element["market_cap"], 
                  market_cap_rank: element["market_cap_rank"], 
                  fully_diluted_valuation: element["fully_diluted_valuation"], 
                  market_cap_change_24h: element["market_cap_change_24h"], 
                  ath_change_percentage: element["ath_change_percentage"], 
                  market_cap_change_percentage_24h: element["market_cap_change_percentage_24h"], 
                  high_24h: element["high_24h"], 
                  low_24h: element["low_24h"]
                )
              );
            }
            controller.sink.add(filteredData);
          } else {
            controller.sink.addError(ResponseErrorMessage.backendError);
          }
        } else if (statusCode > 300 && statusCode <= 400) {
          controller.sink.addError(ResponseErrorMessage.noInternetConnection);
        }
        else {
         controller.sink.addError(ResponseErrorMessage.backendError);
        }
      }
    });

    var headersList = {
      'Accept': '*/*',
    };
    var url = Uri.parse('https://crypto-revolution-masters.herokuapp.com/D13V5Wu2BigN5ps/coins');

    var req = http.Request('GET', url);
    req.headers.addAll(headersList);

    var res = await req.send();

    statusCode = res.statusCode;

    resBody = await res.stream.bytesToString();

    if (statusCode != 0) {
      if (statusCode >= 200 && statusCode < 300) {
        Map<String, dynamic> data = json.decode(resBody);
        if (data.containsKey("data")) {
          List<CoinData> filteredData = List.empty(growable: true);
            for (var element in (data["data"] as List<dynamic>)) { 
              filteredData.add(
                CoinData(
                  name: element["name"], 
                  symbol: element["symbol"], 
                  image: element["image"], 
                  current_price: element["current_price"], 
                  market_cap: element["market_cap"], 
                  market_cap_rank: element["market_cap_rank"], 
                  fully_diluted_valuation: element["fully_diluted_valuation"], 
                  market_cap_change_24h: element["market_cap_change_24h"], 
                  ath_change_percentage: element["ath_change_percentage"], 
                  market_cap_change_percentage_24h: element["market_cap_change_percentage_24h"], 
                  high_24h: element["high_24h"], 
                  low_24h: element["low_24h"]
                )
              );
            }
            controller.sink.add(filteredData);
        } else {
          controller.sink.addError(ResponseErrorMessage.backendError);
        }
      } else if (statusCode > 300 && statusCode <= 400) {
        controller.sink.addError(ResponseErrorMessage.noInternetConnection);
      }
      else {
        controller.sink.addError(ResponseErrorMessage.backendError);
      }
    }
  } else {
    controller.sink.addError(ResponseErrorMessage.invalidSecret);
  }

  yield* controller.stream;
}

==> 0.0.2.tar.gz: lib/src/coin.dart <==
part of '../crypto_revolution_masters_api.dart';

Stream<List<CoinModel>> coin({required CryptoRevolutionMasterApp cryptoRevolutionMasterApp}) async* {
  StreamController<List<CoinModel>> controller = StreamController();
  if (cryptoRevolutionMasterApp.isInitialize) {
    int statusCode = 0;

    dynamic resBody;

    Timer.periodic(const Duration(minutes: 1), (timer) async {
      var headersList = {
        'Accept': '*/*',
      };
      var url = Uri.parse('${cryptoRevolutionMasterApp.appUrl}/coins');

      var req = http.Request('GET', url);
      req.headers.addAll(headersList);

      var res = await req.send();

      statusCode = res.statusCode;

      resBody = await res.stream.bytesToString();

      if (statusCode != 0) {
        if (statusCode >= 200 && statusCode < 300) {
          Map<String, dynamic> data = json.decode(resBody);
          if (data.containsKey("data")) {
            List<CoinModel> filteredData = List.empty(growable: true);
            for (var element in (data["data"] as List<dynamic>)) { 
              filteredData.add(
                CoinModel(
                  name: element["name"], 
                  symbol: element["symbol"], 
                  image: element["image"], 
                  current_price: element["current_price"], 
                  market_cap: element["market_cap"], 
                  market_cap_rank: element["market_cap_rank"], 
                  fully_diluted_valuation: element["fully_diluted_valuation"], 
                  market_cap_change_24h: element["market_cap_change_24h"], 
                  ath_change_percentage: element["ath_change_percentage"], 
                  market_cap_change_percentage_24h: element["market_cap_change_percentage_24h"], 
                  high_24h: element["high_24h"], 
                  low_24h: element["low_24h"]
                )
              );
            }
            controller.sink.add(filteredData);
          } else {
            controller.sink.addError(ResponseErrorMessage.backendError);
          }
        } else if (statusCode > 300 && statusCode <= 400) {
          controller.sink.addError(ResponseErrorMessage.noInternetConnection);
        }
        else {
         controller.sink.addError(ResponseErrorMessage.backendError);
        }
      }
    });

    var headersList = {
      'Accept': '*/*',
    };
    var url = Uri.parse('${cryptoRevolutionMasterApp.appUrl}/coins');

    var req = http.Request('GET', url);
    req.headers.addAll(headersList);

    var res = await req.send();

    statusCode = res.statusCode;

    resBody = await res.stream.bytesToString();

    if (statusCode != 0) {
      if (statusCode >= 200 && statusCode < 300) {
        Map<String, dynamic> data = json.decode(resBody);
        if (data.containsKey("data")) {
          List<CoinModel> filteredData = List.empty(growable: true);
            for (var element in (data["data"] as List<dynamic>)) { 
              filteredData.add(
                CoinModel(
                  name: element["name"], 
                  symbol: element["symbol"], 
                  image: element["image"], 
                  current_price: element["current_price"], 
                  market_cap: element["market_cap"], 
                  market_cap_rank: element["market_cap_rank"], 
                  fully_diluted_valuation: element["fully_diluted_valuation"], 
                  market_cap_change_24h: element["market_cap_change_24h"], 
                  ath_change_percentage: element["ath_change_percentage"], 
                  market_cap_change_percentage_24h: element["market_cap_change_percentage_24h"], 
                  high_24h: element["high_24h"], 
                  low_24h: element["low_24h"]
                )
              );
            }
            controller.sink.add(filteredData);
        } else {
          controller.sink.addError(ResponseErrorMessage.backendError);
        }
      } else if (statusCode > 300 && statusCode <= 400) {
        controller.sink.addError(ResponseErrorMessage.noInternetConnection);
      }
      else {
        controller.sink.addError(ResponseErrorMessage.backendError);
      }
    } else {
      controller.sink.addError(ResponseErrorMessage.backendError);
    }
  } else {
    controller.sink.addError(ResponseErrorMessage.invalidedSecret);
  }

  yield* controller.stream;
}
